@@ -15,7 +15,8 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, Mapping, Sequence, Type, Union, overload
+from decimal import Decimal
+from typing import Any, Dict, Mapping, Sequence, Set, Type, Union, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -308,7 +309,28 @@ class DynamoDBClient(BaseClient):
         self,
         *,
         TableName: str,
-        Key: Mapping[str, AttributeValueTypeDef],
+        Key: Mapping[
+            str,
+            Union[
+                AttributeValueTypeDef,
+                Union[
+                    bytes,
+                    bytearray,
+                    str,
+                    int,
+                    Decimal,
+                    bool,
+                    Set[int],
+                    Set[Decimal],
+                    Set[str],
+                    Set[bytes],
+                    Set[bytearray],
+                    Sequence[Any],
+                    Mapping[str, Any],
+                    None,
+                ],
+            ],
+        ],
         Expected: Mapping[str, ExpectedAttributeValueTypeDef] = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
         ReturnValues: ReturnValueType = ...,
@@ -316,7 +338,28 @@ class DynamoDBClient(BaseClient):
         ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = ...,
         ConditionExpression: str = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
-        ExpressionAttributeValues: Mapping[str, AttributeValueTypeDef] = ...
+        ExpressionAttributeValues: Mapping[
+            str,
+            Union[
+                AttributeValueTypeDef,
+                Union[
+                    bytes,
+                    bytearray,
+                    str,
+                    int,
+                    Decimal,
+                    bool,
+                    Set[int],
+                    Set[Decimal],
+                    Set[str],
+                    Set[bytes],
+                    Set[bytearray],
+                    Sequence[Any],
+                    Mapping[str, Any],
+                    None,
+                ],
+            ],
+        ] = ...
     ) -> DeleteItemOutputTypeDef:
         """
         Deletes a single item in a table by primary key.
@@ -477,7 +520,27 @@ class DynamoDBClient(BaseClient):
         self,
         *,
         Statement: str,
-        Parameters: Sequence[AttributeValueTypeDef] = ...,
+        Parameters: Sequence[
+            Union[
+                AttributeValueTypeDef,
+                Union[
+                    bytes,
+                    bytearray,
+                    str,
+                    int,
+                    Decimal,
+                    bool,
+                    Set[int],
+                    Set[Decimal],
+                    Set[str],
+                    Set[bytes],
+                    Set[bytearray],
+                    Sequence[Any],
+                    Mapping[str, Any],
+                    None,
+                ],
+            ]
+        ] = ...,
         ConsistentRead: bool = ...,
         NextToken: str = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
@@ -544,7 +607,28 @@ class DynamoDBClient(BaseClient):
         self,
         *,
         TableName: str,
-        Key: Mapping[str, AttributeValueTypeDef],
+        Key: Mapping[
+            str,
+            Union[
+                AttributeValueTypeDef,
+                Union[
+                    bytes,
+                    bytearray,
+                    str,
+                    int,
+                    Decimal,
+                    bool,
+                    Set[int],
+                    Set[Decimal],
+                    Set[str],
+                    Set[bytes],
+                    Set[bytearray],
+                    Sequence[Any],
+                    Mapping[str, Any],
+                    None,
+                ],
+            ],
+        ],
         AttributesToGet: Sequence[str] = ...,
         ConsistentRead: bool = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
@@ -659,7 +743,28 @@ class DynamoDBClient(BaseClient):
         self,
         *,
         TableName: str,
-        Item: Mapping[str, AttributeValueTypeDef],
+        Item: Mapping[
+            str,
+            Union[
+                AttributeValueTypeDef,
+                Union[
+                    bytes,
+                    bytearray,
+                    str,
+                    int,
+                    Decimal,
+                    bool,
+                    Set[int],
+                    Set[Decimal],
+                    Set[str],
+                    Set[bytes],
+                    Set[bytearray],
+                    Sequence[Any],
+                    Mapping[str, Any],
+                    None,
+                ],
+            ],
+        ],
         Expected: Mapping[str, ExpectedAttributeValueTypeDef] = ...,
         ReturnValues: ReturnValueType = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
@@ -667,7 +772,28 @@ class DynamoDBClient(BaseClient):
         ConditionalOperator: ConditionalOperatorType = ...,
         ConditionExpression: str = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
-        ExpressionAttributeValues: Mapping[str, AttributeValueTypeDef] = ...
+        ExpressionAttributeValues: Mapping[
+            str,
+            Union[
+                AttributeValueTypeDef,
+                Union[
+                    bytes,
+                    bytearray,
+                    str,
+                    int,
+                    Decimal,
+                    bool,
+                    Set[int],
+                    Set[Decimal],
+                    Set[str],
+                    Set[bytes],
+                    Set[bytearray],
+                    Sequence[Any],
+                    Mapping[str, Any],
+                    None,
+                ],
+            ],
+        ] = ...
     ) -> PutItemOutputTypeDef:
         """
         Creates a new item, or replaces an old item with a new item.
@@ -689,13 +815,55 @@ class DynamoDBClient(BaseClient):
         QueryFilter: Mapping[str, ConditionTypeDef] = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
         ScanIndexForward: bool = ...,
-        ExclusiveStartKey: Mapping[str, AttributeValueTypeDef] = ...,
+        ExclusiveStartKey: Mapping[
+            str,
+            Union[
+                AttributeValueTypeDef,
+                Union[
+                    bytes,
+                    bytearray,
+                    str,
+                    int,
+                    Decimal,
+                    bool,
+                    Set[int],
+                    Set[Decimal],
+                    Set[str],
+                    Set[bytes],
+                    Set[bytearray],
+                    Sequence[Any],
+                    Mapping[str, Any],
+                    None,
+                ],
+            ],
+        ] = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         ProjectionExpression: str = ...,
         FilterExpression: str = ...,
         KeyConditionExpression: str = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
-        ExpressionAttributeValues: Mapping[str, AttributeValueTypeDef] = ...
+        ExpressionAttributeValues: Mapping[
+            str,
+            Union[
+                AttributeValueTypeDef,
+                Union[
+                    bytes,
+                    bytearray,
+                    str,
+                    int,
+                    Decimal,
+                    bool,
+                    Set[int],
+                    Set[Decimal],
+                    Set[str],
+                    Set[bytes],
+                    Set[bytearray],
+                    Sequence[Any],
+                    Mapping[str, Any],
+                    None,
+                ],
+            ],
+        ] = ...
     ) -> QueryOutputTypeDef:
         """
         You must provide the name of the partition key attribute and a single value for
@@ -755,14 +923,56 @@ class DynamoDBClient(BaseClient):
         Select: SelectType = ...,
         ScanFilter: Mapping[str, ConditionTypeDef] = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
-        ExclusiveStartKey: Mapping[str, AttributeValueTypeDef] = ...,
+        ExclusiveStartKey: Mapping[
+            str,
+            Union[
+                AttributeValueTypeDef,
+                Union[
+                    bytes,
+                    bytearray,
+                    str,
+                    int,
+                    Decimal,
+                    bool,
+                    Set[int],
+                    Set[Decimal],
+                    Set[str],
+                    Set[bytes],
+                    Set[bytearray],
+                    Sequence[Any],
+                    Mapping[str, Any],
+                    None,
+                ],
+            ],
+        ] = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         TotalSegments: int = ...,
         Segment: int = ...,
         ProjectionExpression: str = ...,
         FilterExpression: str = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
-        ExpressionAttributeValues: Mapping[str, AttributeValueTypeDef] = ...,
+        ExpressionAttributeValues: Mapping[
+            str,
+            Union[
+                AttributeValueTypeDef,
+                Union[
+                    bytes,
+                    bytearray,
+                    str,
+                    int,
+                    Decimal,
+                    bool,
+                    Set[int],
+                    Set[Decimal],
+                    Set[str],
+                    Set[bytes],
+                    Set[bytearray],
+                    Sequence[Any],
+                    Mapping[str, Any],
+                    None,
+                ],
+            ],
+        ] = ...,
         ConsistentRead: bool = ...
     ) -> ScanOutputTypeDef:
         """
@@ -885,7 +1095,28 @@ class DynamoDBClient(BaseClient):
         self,
         *,
         TableName: str,
-        Key: Mapping[str, AttributeValueTypeDef],
+        Key: Mapping[
+            str,
+            Union[
+                AttributeValueTypeDef,
+                Union[
+                    bytes,
+                    bytearray,
+                    str,
+                    int,
+                    Decimal,
+                    bool,
+                    Set[int],
+                    Set[Decimal],
+                    Set[str],
+                    Set[bytes],
+                    Set[bytearray],
+                    Sequence[Any],
+                    Mapping[str, Any],
+                    None,
+                ],
+            ],
+        ],
         AttributeUpdates: Mapping[str, AttributeValueUpdateTypeDef] = ...,
         Expected: Mapping[str, ExpectedAttributeValueTypeDef] = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
@@ -895,7 +1126,28 @@ class DynamoDBClient(BaseClient):
         UpdateExpression: str = ...,
         ConditionExpression: str = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
-        ExpressionAttributeValues: Mapping[str, AttributeValueTypeDef] = ...
+        ExpressionAttributeValues: Mapping[
+            str,
+            Union[
+                AttributeValueTypeDef,
+                Union[
+                    bytes,
+                    bytearray,
+                    str,
+                    int,
+                    Decimal,
+                    bool,
+                    Set[int],
+                    Set[Decimal],
+                    Set[str],
+                    Set[bytes],
+                    Set[bytearray],
+                    Sequence[Any],
+                    Mapping[str, Any],
+                    None,
+                ],
+            ],
+        ] = ...
     ) -> UpdateItemOutputTypeDef:
         """
         Edits an existing item's attributes, or adds a new item to the table if it does
